@@ -27,7 +27,7 @@ class SimpleText(models.Model):
     def get_absolute_url(self):
         return ('simpletext_detail_view_name', [str(self.id)])
 
-import categories
+#import categories
 
-categories.register_fk(SimpleText, 'primary_category', {'related_name':'simpletext_primary_set'})
-categories.register_m2m(SimpleText, 'cats', )
\ No newline at end of file
+#categories.register_fk(SimpleText, 'primary_category', {'related_name':'simpletext_primary_set'})
+#categories.register_m2m(SimpleText, 'cats', )
\ No newline at end of file
